# React Canvas Polygons

It is a react component that helps you draw line rectangles and any polygon with canvas on top of images.

Everything that you draw is stored in a state. You can access this state through the property `onCompleteDraw`.

This component was designed to draw fences which are used by computer vision application in the back end.

The points saved are relative to the canvas size. It follows the browser coordinate system (0, 0) on the top left.

## Warning: On version 1.1.10 there is a breaking change. The onCompleteDraw was renamed to onDataUpdate and
a new callback function was added onFinishDraw.

## Installation

```
npm i -E react-canvas-polygons
```

## Component Props

Prop | Type | Default | Req | Description
--- | --- | --- | --- | ---
**brushSize** | `Number` |  `2` | - | BrushSize to draw
**canUndo** | `Boolean` |  `false` | - | CanUndo
**color** | `String` |  `'#000000'` | - | Color of what we want draw
**height** | `Number` |  `300` | - | the height of the canvas
**imgSrc** | `String` |  | - | Background image to canvas;
**initialData** | `Object` |  | - | Is the data to be be draw when load the component
**onCompleteDraw** | `Function` |  | - | This is a callback function that we be called everytime a shape finish to draw
**tool** | `Enum('Line','Polygon','Rectangle')` |  `'Line'` | - | Shapes that you can select to draw
**width** | `Number` |  `300` | - | The width of canvas

## Usage Example

```js
import React, { Suspense } from 'react';
import type from 'prop-types';
import { CircularProgress } from '@material-ui/core';
import Canvas from 'react-canvas-polygons';

class DrawCanvas extends React.PureComponent {

    handleCleanCanva = () => this.canva.cleanCanvas();

    render() {
        const { imageInfo, tool, onCompleteDraw, fenceData } = this.props;
        const imageInfoLength = Object.keys(imageInfo).length === 0;

        return(
            <Suspense fallback={<CircularProgress color="secondary" />}>
                <button variant="outlined" style={{ marginBottom: '20px' }}
                    onClick={this.handleCleanCanva}
                >
                    Clean Canvas
                </button>
                {imageInfoLength &&
                    <CircularProgress color="secondary" />
                }
                <Canvas
                    ref={canva => this.canva = canva}
                    imgSrc={imageInfo.url}
                    height={imageInfo.height}
                    width={imageInfo.width}
                    tool={tool}
                    onCompleteDraw={onCompleteDraw}
                    initialData={fenceData}
                />
            </Suspense>
        );
    }
}

export default DrawCanvas;

DrawCanvas.propTypes = {
    tool: type.string,
    imageInfo: type.object,
};
```

## Cleaning the canvas

Use a reference to the object and call cleanCanvas() method like demonstrate in the example above

```js
    handleCleanCanva = () => this.canva.cleanCanvas();
```

This will clean the canvas and reset the component state.

## Exampe of State Saved

```js
{
    "Line": [
        [
            [
                39,
                46
            ],
            [
                28,
                181
            ]
        ]
    ],
    "Rectangle": [
        [
            [
                207,
                152
            ],
            [
                268,
                215
            ]
        ]
    ],
    "Polygon_CBC39F42": [
        [
            113,
            52
        ],
        [
            65,
            136
        ],
        [
            101,
            167
        ],
        [
            158,
            141
        ],
        [
            100,
            90
        ]
    ],
    "Polygon_CBC39F44": [
        [
            113,
            52
        ],
        [
            65,
            136
        ],
        [
            101,
            167
        ],
        [
            158,
            141
        ],
        [
            167,
            69
        ]
    ]
}

```
